==> spellathon-5.47.tar.gz: spellathon-5.47/src/logic/dispwordsbuf.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef DISPWORDBUF_H
#define DISPWORDBUF_H

#include <string>
#include <vector>

using std::vector;
using std::string;

namespace Spellathon
{
	class DispWordsBuf
	{
	public:
		DispWordsBuf() : sol_(0), hint_(0), widx_(0), fw_(9), wpl_(4) {}
		~DispWordsBuf() { destroy(); }

		void destroy();
		void init(const vector<string> &w, int wpl = 4, int fw = 9);	

		const char* ansiColor() { return format(hint_, ansifmt_); }
		const char* html() { return format(hint_, htmlfmt_); }

		int setWord(const string w);
		bool setHint();
		int hintLevel() const { return hlevel_; }
		int entered7() const { return entered7_; }
		int nSetWords() const { return (int)setwords_.size(); }
		int nWords() const { return (int)words_.size(); }
		void setWpl(int n) { if (wpl_ != n) wpl_ = n; }
		int wpl() const { return wpl_; }
		int fw() const { return fw_; }
		void setSol() { idx_ = -1; solved_ = true; strcpy(hint_, sol_); }
	private:
		const char* format(const char *buf, const char *fmt_type[]);
	private:
		enum { 
			FMT_BEG, FMT_BEG2, FMT_BEG3, FMT_BEG4, 
			FMT_BEG5, FMT_BEG6, FMT_BEG7, FMT_BEG8, 
			FMT_END, FMT_END2, FMT_END3, FMT_END4, 
			FMT_END5, FMT_END6, FMT_END7, FMT_END8, 
			FMT_SPC, FMT_NL 
		};

		char		*sol_;		
		char		*hint_;
		string		fmt_;
		char		(*widx_)[2];
		const char	*ansifmt_[18];
		const char	*htmlfmt_[18];
		int			sz_;		/* buffer size */
		int			hlevel_;	/* hint level */
		int			idx_;
		int			entered7_;
		bool		solved_;
		int 		fw_;		/* field width */
		int 		wpl_;		/* words per line */
	
		vector<string> words_;		/* solution words */
		vector<string> setwords_;	/*correct words entered by usr*/
		vector<string>::iterator p_;

		DispWordsBuf(const DispWordsBuf &);
		DispWordsBuf & operator=(const DispWordsBuf &);
	};
}

#endif /* DISPWORDBUF_H */

==> spellathon-5.53.tar.gz: spellathon-5.53/src/logic/dispwordsbuf.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef DISPWORDBUF_H
#define DISPWORDBUF_H

#include <string>
#include <vector>

using std::vector;
using std::string;

namespace Spellathon
{
	class DispWordsBuf
	{
	public:
		DispWordsBuf();
		~DispWordsBuf() {}

		void init(const vector<string> &words, int wpl = 4, int fw = 9);	

		const char * ansiColor() { return format(hint_, ansifmt_); }
		const char * html() { return format(hint_, htmlfmt_); }

		int setWord(const string word);
		bool setHint();
		void setWpl(int n) { if (wpl_ != n) wpl_ = n; }
		void setSolved() { curidx_ = -1; solved_ = true; hint_ = sol_; }

		int hintLevel() const { return hlevel_; }
		int entered7() const { return entered7_; }
		int nSetWords() const { return nsetwords_; }
		int nWords() const { return (int)sol_.size(); }
		int wpl() const { return wpl_; }
		int fw() const { return fw_; }
		int solved() const { return solved_; }

	private:
		const char * format(vector<string> &buf, const char *fmt_type[]);

	private:
		enum { 
			FMT_BEG, FMT_BEG2, FMT_BEG3, FMT_BEG4, 
			FMT_BEG5, FMT_BEG6, FMT_BEG7, FMT_BEG8, 
			FMT_END, FMT_END2, FMT_END3, FMT_END4, 
			FMT_END5, FMT_END6, FMT_END7, FMT_END8, 
			FMT_SPC, FMT_NL 
		};

		const char	*ansifmt_[18];
		const char	*htmlfmt_[18];

		string 		fmt_;
		vector<int>	setidx_;
		int			sz_;		/* buffer size */
		int			hlevel_;	/* hint level */
		int			curidx_;
		int			entered7_;
		bool		solved_;
		int 		fw_;		/* field width */
		int 		wpl_;		/* words per line */
		int			nsetwords_;
	
		vector<string> sol_;		/* solution words */
		vector<string> hint_;
		vector<string>::iterator p_;

		DispWordsBuf(const DispWordsBuf &);
		DispWordsBuf & operator=(const DispWordsBuf &);
	};
}

#endif /* DISPWORDBUF_H */
